Documentation
¶
Overview ¶
Alias public types and functions for the package gimbap.
Index ¶
- func GetProvider[T interface{}](a GimbapApp, prov T) (ret T)
- type AppOption
- type Controller
- type ControllerOption
- type GimbapApp
- type IController
- type IMicroService
- type IServerEngine
- type MicroServiceProvider
- type MicroServiceProviderOption
- type Module
- type ModuleOption
- type Provider
- type ProviderOption
- type RouteSpec
- type RuntimeOptions
- type ServerEngineOption
- type TLSOption
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetProvider ¶
func GetProvider[T interface{}](a GimbapApp, prov T) (ret T)
Function to get a provider from the app.
Provide the app and the provider type to get the provider instance. If the provider is not found, it will panic.
Types ¶
type Controller ¶ added in v0.0.4
type Controller = controller.Controller
type aliases for public apis
func DefineController ¶
func DefineController(option ControllerOption) *Controller
Define a controller.
Defines a special provider that is used to handle RESTful requests. The controller will be registered to the app and can be injected to the other controllers.
type ControllerOption ¶
type ControllerOption = controller.ControllerOption
type aliases for public apis
type MicroServiceProvider ¶ added in v0.0.5
type MicroServiceProvider = microservice.MicroServiceProvider
type aliases for public apis
func DefineMicroService ¶ added in v0.0.5
func DefineMicroService(option MicroServiceProviderOption) *MicroServiceProvider
Define a microservice
Define a special provider for microservices
type MicroServiceProviderOption ¶ added in v0.0.5
type MicroServiceProviderOption = microservice.MicroServiceProviderOption
type aliases for public apis
type Module ¶
type aliases for public apis
func DefineModule ¶
func DefineModule(option ModuleOption) *Module
Define a module.
This defines a module with the given option. The module is used to determine the dependencies of the providers.
type Provider ¶ added in v0.0.4
Provider related
func DefineProvider ¶
func DefineProvider(option ProviderOption) *Provider
Define a provider.
This defines a provider with the given option. The provider will be registered to the app and can be injected to the controllers.
type ServerEngineOption ¶
type ServerEngineOption = engine.ServerEngineOption
type aliases for public apis
Directories
¶
| Path | Synopsis |
|---|---|
|
Experimental Gimbap Dependency Manager
|
Experimental Gimbap Dependency Manager |
|
File: http-engine.go
|
File: http-engine.go |
|
File: module.go
|
File: module.go |
|
file: provider.go
|
file: provider.go |